==> nextcloud-20.0.14.tgz: nextcloud/apps/federation/l10n/fr.js <==
OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "Ajouté à la liste des serveurs de confiance",
    "Server is already in the list of trusted servers." : "Le serveur est déjà dans la liste des serveurs de confiance.",
    "No server to federate with found" : "Aucun serveur avec lequel fédérer n'a été trouvé",
    "Could not add server" : "Impossible d'ajouter le serveur",
    "Trusted servers" : "Serveurs de confiance",
    "Federation" : "Fédération",
    "Federation allows you to connect with other trusted servers to exchange the user directory." : "Une fédération vous permet de vous connecter avec d'autres serveurs de confiance pour échanger la liste des utilisateurs.",
    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing." : "Une fédération vous permet de vous connecter avec d'autres serveurs de confiance pour échanger la liste des utilisateurs. Par exemple, ce sera utilisé pour auto-compléter les utilisateurs externes lors du partage fédéré.",
    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "Une fédération vous permet de vous connecter avec d'autres serveurs de confiance pour échanger la liste des utilisateurs. Par exemple, ce sera utilisé pour auto-compléter les utilisateurs externes lors du partage fédéré. Il n'est pas nécessaire d'ajouter un serveur comme serveur de confiance afin de créer un partage fédéré.",
    "+ Add trusted server" : "+ Ajouter un serveur de confiance",
    "Trusted server" : "Serveur de confiance",
    "Add" : "Ajouter"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-24.0.5.tgz: nextcloud/apps/federation/l10n/fr.js <==
OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "Ajouté à la liste des serveurs de confiance",
    "Server is already in the list of trusted servers." : "Le serveur est déjà dans la liste des serveurs de confiance.",
    "No server to federate with found" : "Aucun serveur avec lequel fédérer n'a été trouvé",
    "Could not add server" : "Impossible d'ajouter le serveur",
    "Trusted servers" : "Serveurs de confiance",
    "Federation" : "Fédération",
    "Federation allows you to connect with other trusted servers to exchange the user directory." : "Une fédération vous permet de vous connecter avec d'autres serveurs de confiance pour échanger la liste des utilisateurs.",
    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing." : "Une fédération vous permet de vous connecter avec d'autres serveurs de confiance pour échanger la liste des utilisateurs. Par exemple, ce sera utilisé pour auto-compléter les utilisateurs externes lors du partage fédéré.",
    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "Une fédération vous permet de vous connecter avec d'autres serveurs de confiance pour échanger la liste des utilisateurs. Par exemple, ce sera utilisé pour auto-compléter les utilisateurs externes lors du partage fédéré. Il n'est pas nécessaire d'ajouter un serveur comme serveur de confiance afin de créer un partage fédéré.",
    "+ Add trusted server" : "+ Ajouter un serveur de confiance",
    "Trusted server" : "Serveur de confiance",
    "Add" : "Ajouter"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
